@@ -1,6 +1,5 @@
 __all__ = ['activation',
            'error',
-           'matrix',
            'model',
            'network_data',
            'one_hot_encode',
@@ -14,4 +13,7 @@ __all__ = ['activation',
            'RNN',
            'datasets']
 
-from phidnet import *
\ No newline at end of file
+from phidnet import *
+from phidnet.matrix import matrix
+from phidnet.matrix.matrix import array
+from phidnet.matrix.matrix_class import Matrix
\ No newline at end of file
